#
# spec file for package scintilla
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define so_ver 5.3
%define _ver %{so_ver}.6
%define tar_ver 536
%define libname libscintilla5
Name:           scintilla
Version:        %{_ver}
Release:        1.1
Summary:        A source code editing component
License:        MIT
URL:            http://www.scintilla.org
Source:         http://sourceforge.net/projects/scintilla/files/scintilla/%{version}/%{name}%{tar_ver}.tgz
Patch0:         %{name}-shared.patch
Patch1:         %{name}-add-missing-includes.patch

BuildRequires:  gcc-c++
BuildRequires:  libtool
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(glib-2.0)
BuildRequires:  pkgconfig(gtk+-3.0)
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
Scintilla is a code editing component. It includes features for
editing and debugging source code, such as syntax styling, error
indicators, code completion and call tips. The selection margin can
contain breakpoint markers and the current line. It can use
proportional fonts, multiple fonts and different colors at the same
time.

%package -n %{libname}
Summary:        A source code editing component

%description -n %{libname}
Scintilla is a code editing component. It includes features for
editing and debugging source code, such as syntax styling, error
indicators, code completion and call tips. The selection margin can
contain breakpoint markers and the current line. It can use
proportional fonts, multiple fonts and different colors at the same
time.

%package -n libscintilla-devel
Summary:        Development files for Scintilla, a code editing component
Requires:       %{libname} = %{version}
Requires:       pkgconfig
Requires:       pkgconfig(glib-2.0)
Requires:       pkgconfig(gtk+-3.0)

%description -n libscintilla-devel
Scintilla is a code editing component. It includes features for
editing and debugging source code, such as syntax styling, error
indicators, code completion and call tips.

This subpackage contains the header files for developing
applications that want to make use of the Scintilla library.

%prep
%autosetup -p1 -n %{name}

%build
%make_build -C gtk GTK3=1 LIBDIR=%{_libdir} VERSION=`echo %{so_ver} | sed 's|\.0*|:|'` static

%install
mkdir -p %{buildroot}%{_includedir}/%{name}/src
cp include/* %{buildroot}%{_includedir}/%{name}
cp src/*.h %{buildroot}%{_includedir}/%{name}/src

mkdir -p %{buildroot}%{_libdir}
libtool --mode=install install bin/libscintilla.la %{buildroot}%{_libdir}
# Delete libtool archive and static lib
find %{buildroot}%{_libdir} -name "*.a" -delete -print
find %{buildroot}%{_libdir} -name "*.la" -delete -print

rmdir %{buildroot}%{_includedir}/%{name}/src || :

%post -n %{libname} -p %run_ldconfig
%postun -n %{libname} -p %run_ldconfig

%files -n %{libname}
%license License.txt
%{_libdir}/libscintilla.so.*

%files -n libscintilla-devel
%license License.txt
%doc doc
%{_libdir}/libscintilla.so
%{_includedir}/%{name}/

%changelog
* Wed Aug  2 2023 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 5.3.6:
  * Redraw calltip after showing as didn't update when size of new
    text exactly same as previous. Feature #1486.
  * On Qt, for IMEs, update micro focus when selection changes.
    This may move the location of IME popups to align with the
    caret.
  * On Qt, implement replacement for IMEs which may help with
    actions like reconversion. This is similar to
    delete-surrounding on GTK.
* Sat Jun 10 2023 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 5.3.5:
  * On Qt, stop movement of IME candidate box.
  * On Qt, report correct caret position within paragraph for IME
    retrieve surrounding text.
* Sun Apr  2 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 5.3.4:
  * Add multithreaded wrap to significantly improve performance of
    wrapping large files.
  * More typesafe bindings of *Full APIs in ScintillaCall.
  * Fix overlapping of text with line end wrap marker.
  * Fix clipping of line end wrap symbol for
    SC_WRAPVISUALFLAGLOC_END_BY_TEXT.
  * Where a multi-byte character contains multiple styles, display
    each byte as a representation. This makes it easier to see and
    fix lexers that change styles mid-character, commonly because
    they use fixed size buffers.
  * Fix a potential crash with autocompletion list fill-ups where a
    SCN_CHARADDED handler retriggered an autocompletion list, but
    with no items that match the typed character.
- Rebase patch with quilt.
- Bump sover following upstream changes.
- Add scintilla-add-missing-includes.patch: Needed for scite when
  building with system scintilla.
* Tue Feb 14 2023 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 5.3.3:
  * Fix SCI_LINESJOIN bug where carriage returns were incorrectly
    retained. Bug #2372.
  * Fix SCI_VERTICALCENTRECARET to update the vertical scroll
    position.
  * When an autocompletion list is shown in response to
    SCN_CHARADDED, do not process character as fill-up or stop.
  * On GTK, support IME context. Feature #1476.
  * On Qt, fix indicator drawing past left of text pane over
    margin. Bug #2373, Bug #1956.
  * On Qt, allow scrolling with mouse wheel when scroll bar hidden.
* Mon Dec 26 2022 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 5.3.2:
  - Add SCI_REPLACETARGETMINIMAL to change text without causing
    unchanged prefix and suffix to be marked as modified in change
    history.
  - Draw background colour for EOL annotations with standard and
    boxed visuals.
  - Add SCI_GETSTYLEDTEXTFULL to support 64-bit document positions
    on Win32 replacing SCI_GETSTYLEDTEXT which is not safe for
    huge documents. Feature #1455.
  - Send SCN_AUTOCCOMPLETED for SCI_AUTOCSHOW triggering insertion
    because of SCI_AUTOCSETCHOOSESINGLE mode. Feature #1459.
  - Change 'paragraph up' commands SCI_PARAUP and SCI_PARAUPEXTEND
    to go to the start position of the paragraph containing the
    caret. Bug #2363.
  - Change release compilation optimization option to favour speed
    over space. -O2 for MSVC and -O3 for gcc and clang.
  - On Qt, implement SCI_SETRECTANGULARSELECTIONMODIFIER for all
    platforms.
  - On Qt, allow string form XPM images for SCI_REGISTERIMAGE.
- Minor refreshing of scintilla-shared.patch to apply cleanly.
* Mon Oct 31 2022 Atri Bhattacharya <badshah400@gmail.com>
- Update to versoin 5.3.1:
  * Added SCI_STYLESETINVISIBLEREPRESENTATION to make it easier to
    edit around invisible text (Feature #1453).
  * Removed NotifyLexerChanged notification from DocWatcher. This
    is a private interface but could be used by independent
    platform layers and was exposed by ScintillaDocument in the Qt
    implementation of ScintillaEdit.
  * Draw lines more consistently in SC_PHASES_TWO and
    SC_PHASES_ONE modes by clipping drawing to just the line
    rectangle.
  * Draw SC_MARK_BAR markers underneath other markers as they
    often cover multiple lines for change history and other
    markers mark individual lines.
  * Enlarge point and point top indicators and scale to be larger
    with larger text.
  * Suppress change history background line shading when printing.
    Bug #2358.
  * Make SCI_LINESCROLL more accurate when width of space not
    integer (Bug #2357).
  * On GTK, fix bug where there were too many or too few lines
    when wrapping (Bug #2349).
* Fri Sep  9 2022 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 5.3.0:
  * Added change history which can display document changes
    (modified, saved, ...) in the margin or in the text.
  * Add SC_MARK_BAR marker and INDIC_POINT_TOP indicator.
  * Improve drawing of rounded rectangles on Direct2D.
  * Line state optimized to avoid excess allocations by always
    allocating for every line.
  * Add SC_FOLDACTION_CONTRACT_EVERY_LEVEL option to contract
    every level for SCI_FOLDALL [Bug #2340].
  * Enable multiline regex for gcc and clang when REGEX_MULTILINE
  * defined [Bug #2338].
  * Stop including STYLE_CALLTIP when calculating line height [Bug
    [#2341]].
  * Fix incorrect display of selection when printing in some modes
    [Bug #2335].
  * Fix crash on Qt when showing autocompletion and the caret
    isn't on a screen.
- Update so versions to match upstream's.
* Wed Jul 13 2022 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 5.2.4:
  * Fix hiding selection when selection layer is
    SC_LAYER_UNDER_TEXT. Bug #2334.
  * Fix bad background colour for additional, secondary, and
    inactive selections when printing. Bug #2335.
  * Fix failures on GTK with non-UTF-8 text when multi-threading
    due to character set conversion code that was not thread-safe.
  * Fix crash when printing on Win32 in bidirectional mode with a
    non-empty selection.
* Wed Jun 22 2022 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 5.2.3:
  * Improve performance of SCI_FOLDALL(SC_FOLDACTION_EXPAND) by
    not lexing whole document as it does not depend on folding
    structure.
  * Fix partial updates and non-responsive scroll bars on Xorg.
    This defers scroll bar changes to an idle task so could affect
    applications that depend on the scroll position being updated.
    Bug #2322, Bug #2196, Bug #2312.
  * Fix problem with horizontally inverted glyphs with buffered
    drawing and WS_EX_LAYOUTRTL set on Win32 GDI. Feature #1435.
  * For Qt 6, fix "modified" signal when text is null but length
    non-0. Bug #2328.
  * Fix pink selection background when printing by making it
    completely transparent.
* Sun May  1 2022 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 5.2.2:
  * Add SCI_GETSTYLEINDEXAT API to return styles over 127 as
    positive integers. Feature #1431.
  * On GTK, scroll horizontally with shift + scroll wheel.
  * Fix crash with unexpected right-to-left text on GTK. Bug
    [#2309].
  * Fix position of end-of-line annotation when fold display text
    is visible. Bug #2320.
  * On Direct2D, support per-monitor text rendering parameters.
    Feature #1432.
* Thu Feb 24 2022 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 5.2.1:
  * Enable multi-threaded layout on GTK.
  * Fix pixmap leak on GTK. Bug #2317.
  * Fix re-entrant painting on GTK to maintain update region.
* Thu Feb 17 2022 Atri Bhattacharya <badshah400@gmail.com>
- Revert to defining tar_ver macro literally to allow
  source_validator and similar services to work with sources.
* Mon Feb 14 2022 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 5.2.0:
  * Add multithreaded layout to significantly improve performance
    for very wide lines. Feature #1427.
  * Made compatible with Qt 6.
  * Fix potential issue with length of buffer for string returning
    APIs in ScintillaEdit on Qt.
  * Fix inaccurate scroll bar when there are annotations and
    wrapping of inserted or deleted text changes number of screen
    lines. Feature #1422.
  * Allow choice of object file directory with makefile by setting
    DIR_O. Bug #2306.
  * On GTK, use fractional positioning to help Chinese characters
    in monospaced fonts line up better with roman characters. Bug
    [#2310].
- Rebase scintilla-shared.patch to apply cleanly.
- Ensure consistent definitions between packager defined macros,
  with less possibility for mismatch.
* Fri Dec 24 2021 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 5.1.5:
  * ScintillaEditPy, Python bindings for Qt using PySide, has been
    removed.
  * When calling SCI_GETTEXT, SCI_GETSELTEXT, and SCI_GETCURLINE
    with a NULL buffer argument to discover the length that should
    be allocated, do not include the terminating NUL in the
    returned value.
  * Fix assertion failure with autocompletion list when order is
    SC_ORDER_CUSTOM or SC_ORDER_PERFORMSORT and the list is empty.
    Bug #2294.
  * On GTK using Wayland, display autocompletion with window on a
    secondary monitor. Bug #2296, Bug #2261.
* Fri Nov 19 2021 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 5.1.4:
  * Add DEL to standard set of space characters for word
    operations.
  * Add CARETSTYLE_CURSES to draw more than 1 caret on curses
    terminal.
  * On GTK, fix primary selection paste within same instance. Bug
    [#2287].
  * On GTK, fix potential crash when closing Scintilla instances
    due to releasing global settings object.
  * GetLineEndTypesSupported returns LineEndType, not int.
* Thu Oct 21 2021 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 5.1.3:
  * Fix bug with SCI_STYLESETCHECKMONOSPACED on Cocoa that led to
    incorrect layout with overlapping text.
- Changes from version 5.1.2:
  * Add SCI_STYLESETCHECKMONOSPACED which can be used to optimize
    fonts that are monospaced over the ASCII graphics characters.
  * Add SC_ELEMENT_FOLD_LINE to set the colour of fold lines. Add
    SC_ELEMENT_HIDDEN_LINE to show where lines are hidden. Feature
    [#1241], Feature #382, Feature #203.
  * Add SCI_SETCARETLINEHIGHLIGHTSUBLINE to highlight just the
    subline containing the caret instead of the whole document
    line. Feature #841.
  * Allow SCI_HIDELINES to hide the first line or all lines which
    can be useful for filtered views.
  * Make negative settings for extra ascent and descent safer by
    ensuring calculated ascent and thus line height is at least 1
    pixel.
  * Fix display of fold lines when wrapped so they are only drawn
    once per line, not on each subline.
  * Fix crash with too many subexpressions in regular expression
    search with SCFIND_CXX11REGEX. Bug #2281.
  * On GTK, fix the line spacing so that underscores and accents
    are visible for some fonts such as DejaVu Sans Mono 10.
  * On GTK, respond to changes in system font scaling by clearing
    any cached layout data.
* Wed Jul 28 2021 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 5.1.1:
  * In DBCS encodings, treat valid DBCS lead byte followed by
    invalid trail byte as single byte. Feature #1408.
  * Searching was optimized for documents that contain mostly
    ASCII text and is often 2-3 times faster. Feature #1381.
  * Word searching behaves more consistently at start and end of
    document.
  * Add SCI_ALLOCATELINES to allocate indices to hold some number
    of lines. This can decrease reallocation overhead when the
    application can count or estimate the number of lines in huge
    files. Feature #1370.
  * Add SCI_AUTOCSETOPTIONS to allow choosing a non-resizeable
    autocompletion list on Win32. Feature #1284.
- Minor rebase of scintilla-shared.patch to apply cleanly.
* Sun Jun 27 2021 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 5.1.0:
  * Add SciFnDirectStatus, a direct access function which also
    returns status. It can be retrieved with
    SCI_GETDIRECTSTATUSFUNCTION. This can avoid calling
    SCI_GETSTATUS after every API to determine failure so can
    improve performance.
  * Add more type-safe wrappers to the API. These are defined in
    include/ScintillaCall.h and implemented in
    call/ScintillaCall.cxx. ScintillaCall throws
    Scintilla::Failure exceptions when a call fails.
  * Add APIs for setting appearance (traditional blob or plain
    text) and colour of representations and support setting a
    representation for the "\r\n" line end sequence.
  * Add SCI_REPLACERECTANGULAR to insert text like a rectangular
    paste.
  * Fixed bug with SCI_GETLASTCHILD. Bug #2260.
  * Fixed gcc link-time-optimization (LTO) compilation. Bug #2259.
- Refresh scintilla-shared.patch to apply against updated version.
- Install license file using %%license.
- Drop fdupes form BuildRequires: no longer needed.
- Minor specfile cleanups.
* Mon Sep 11 2017 jengelh@inai.de
- Fix RPM groups and compact package descriptions.
* Thu Jul 27 2017 badshah400@gmail.com
- Update to version 3.7.5:
  * Added a caret line frame as an alternative visual for
    highlighting the caret line.
  * Added "Reverse Selected Lines" feature.
  * SciTE adds "Select All Bookmarks" command.
  * SciTE adds a save.path.suggestion setting to suggest a file
    name when saving an unnamed buffer.
  * Updated case conversion and character categories to Unicode 9.
  * The Baan lexer recognizes numeric literals in a more compliant
    manner including hexadecimal numbers and exponentials.
  * The Bash lexer recognizes strings in lists in more cases. Bug
    [#1944].
  * The Fortran lexer recognizes a preprocessor line after a line
    continuation &. Bug #1935.
  * The Fortran folder can fold comments. Bug #1936.
  * The PowerShell lexer recognizes escaped quotes in strings. Bug
    [#1929].
  * The Python lexer recognizes identifiers more accurately when
    they include non-ASCII characters.
  * The Python folder treats comments at the end of the file as
    separate from the preceding structure.
  * The YAML lexer recognizes comments in more situations and
    styles a "..." line like a "---" line. Bug #1931.
  * Update scroll bar when annotations added, removed, or
    visibility changed. Feature #1187.
  * Canceling modes with the Esc key preserves a rectangular
    selection. Bug #1940.
  * Builds are made with a sorted list of lexers to be more
    reproducible. Bug #1946.
  * SciTE examines at most 1 MB of a file to automatically
    determine indentation for indent.auto to avoid a lengthy pause
    when loading very large files.
  * SciTE user interface uses lighter colours and fewer 3D
    elements to match current desktop environments.
  * SciTE sets buffer dirty and shows message when file deleted if
    load.on.activate on.
  * SciTE on Windows Find strip Find button works in incremental
    no-close mode. Bug #1926.
- Drop reproducible.patch: fixed upstream.
- Rebase scintilla-shared.patch for update; make it work with -p1
  for use with quilt.
* Sat May 20 2017 bwiedemann@suse.com
- Add reproducible.patch to have constant link-order
  and make build fully reproducible
* Tue Jul 12 2016 tchvatal@suse.com
- Version update to 3.6.6:
  * Various small bugfixes
- Remove support for older distros that are marked as dead
- Update shared patch to set properly cflags:
  * scintilla-shared.patch
* Sun Apr 10 2016 mpluskal@suse.com
- Update to 3.6.4
  * avoids some folding bugs by automatically unfolding and
    improves clipboard robustness on Win32.
* Sat Jan 30 2016 mpluskal@suse.com
- Update to 3.6.3
  * No changelog available
* Fri Nov 20 2015 mpluskal@suse.com
- Update to 3.6.2
  * No changelog available
* Mon Mar 23 2015 p.drouand@gmail.com
- Update to version 3.5.4
  * No changelog available
- Build with gtk3 support for openSUSE > 13.1
- Bump so version to 3
- Add glib2-devel require; new upstream dependency
- Update scintilla-shared.patch
- Remove redundant %%clean section
- Enable parallel building with %%{?_smp_mflags}
* Mon Mar 26 2012 cfarrell@suse.com
- license update: MIT
  License is closely related to the MIT license. Use SPDX format
* Sun Nov 27 2011 coolo@suse.com
- add libtool as buildrequire to avoid implicit dependency
* Mon Oct 17 2011 mhrusecky@suse.cz
- updated to the version 2.29
* Wed Nov 11 2009 mhrusecky@suse.cz
- making sure that no include can be included twice
* Tue Nov 10 2009 mhrusecky@suse.cz
- commenting out fdupes on non-SuSE distro
* Fri Oct 30 2009 mhrusecky@suse.cz
- packaging even src headers (MySQL Workbench need them)
* Fri Oct 30 2009 mhrusecky@suse.cz
- moving headers to the scintilla directory
* Sun Oct 25 2009 mhrusecky@suse.cz
- updated to version 2.01
  - 2.01 changes
  - Fix to positioning rectangular paste when viewing line ends.
  - Don't insert new lines and indentation for line ends at end of
    rectangular paste.
  - When not in additional selection typing mode, cutting a
    rectangular selection removes all of the selected text.
  - Rectangular selections are copied to the clipboard in document
    order, not in the order of selection.
  - SCI_SETCURRENTPOS and SCI_SETANCHOR work in rectangular mode.
  - On GTK+, drag and drop to a later position in the document now
    drops at the position.
  - Fix bug where missing property did not use default value.
  - 2.0 changes
  - Multiple pieces of text can be selected simultaneously by holding
    control whil dragging the mouse. Typing, backspace and delete may
    affect all selections together.
  - Virtual space allows selecting beyond the last character on a line.
  - SciTE on GTK+ path bar is now optional and defaults to off.
  - MagikSF lexer recognises numbers correctly.
  - Folding of Python comments and blank lines improved. Bug #210240.
  - Bug fixed where background colour of last character in document
    leaked past that character.
  - Crash fixed when adding marker beyond last line in document.
    Bug #2830307.
  - Resource leak fixed in SciTE for Windows when printing fails.
    Bug #2816524.
  - Bug fixed on Windows where the system caret was destroyed during
    destruction when another window was using the system caret.
    Bug #2830223.
  - Bug fixed where indentation guides were drawn over text when the
    indentation used a style with a different space width to the
    default style.
  - SciTE bug fixed where box comment added a bare line feed rather
    than the chosen line end. Bug #2818104.
  - Reverted fix that led to wrapping whole document when displaying
    the first line of the document.
  - Export to LaTeX in SciTE fixed to work in more cases and not use
    as much space. Bug #1286548.
  - Bug fixed where EN_CHANGE notification was sent when performing a
    paste operation in a read-only document. Bug #2825485.
  - Refactored code so that Scintilla exposes less of its internal
    implementation and uses the C++ standard library for some basic
    collections. Projects that linked to Scintilla's SString or PropSet
    classes should copy this code from a previous version of Scintilla
    or from SciTE.
* Tue Jul 28 2009 mhrusecky@suse.cz
- updated to version 1.79
  - Scintilla reports memory exhaustion instead of crashing.
  - for more details see http://www.scintilla.org/ScintillaHistory.html
* Tue Jun  2 2009 mhrusecky@suse.cz
- updated to version 1.78
  - allows annotation lines to be displayed beneath each document line and to
    display a margin with different text for each document line
  - for more details see http://www.scintilla.org/ScintillaHistory.html
- not packaging static libraries anymore
* Tue Feb 17 2009 mhrusecky@suse.cz
- forgotten macro expanded - fixed -devel dependencies
* Fri Dec 19 2008 mhrusecky@suse.cz
- New Package (Version 1.77)
